# Database executor

**Техническое название:** executor_invest_helper

## Описание

Database executor — это мощный инструмент для взаимодействия с базой данных мега-крутого телеграм-бота про инвестиции. Этот пакет упрощает выполнение запросов к базе данных и управление данными, что позволяет разработчикам сосредоточиться на создании функционала бота.

## Установка

Для установки пакета используйте pip:

```bash
pip install executor_invest_helper